#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "path", "fs", "@clack/prompts", "@gluestack/cli-utils", "child_process"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const args = process.argv.slice(2);
    let supportedArgs = ['--use-npm', '--use-yarn', '--help', '-h', '--use-pnpm'];
    const path_1 = __importDefault(require("path"));
    const fs_1 = __importDefault(require("fs"));
    const prompts_1 = require("@clack/prompts");
    const cli_utils_1 = require("@gluestack/cli-utils");
    const child_process_1 = require("child_process");
    function installDependencies(projectName, installationMethod) {
        const projectPath = path_1.default.join(process.cwd(), projectName);
        const s = (0, prompts_1.spinner)();
        s.start('⏳ Installing dependencies...');
        try {
            (0, child_process_1.spawnSync)(`mv gitignore .gitignore`, {
                cwd: projectPath,
                stdio: 'inherit',
                shell: true,
            });
        }
        catch (err) {
            prompts_1.log.error(`\x1b[31mError: gitignore file not found in template!\x1b[0m`);
        }
        try {
            (0, child_process_1.spawnSync)(`git init && ${installationMethod} && rm .npmignore && cd ios && pod install`, {
                cwd: projectPath,
                stdio: 'inherit',
                shell: true,
            });
            s.stop(`\x1b[32mDependencies have been installed successfully.\x1b[0m`);
        }
        catch (err) {
            prompts_1.log.error(`\x1b[31mError: ${err}\x1b[0m`);
            prompts_1.log.error('\x1b[31mError installing dependencies:\x1b[0m');
            prompts_1.log.warning(` - Run \x1b[33m yarn \x1b[0m manually!`);
            prompts_1.log.warning(` - Run \x1b[33m pod install \x1b[0m manually!`);
            throw new Error('Error installing dependencies.');
        }
    }
    function main() {
        return __awaiter(this, void 0, void 0, function* () {
            let projectPath = path_1.default.join(path_1.default.resolve(__dirname, '..'), 'src', 'template');
            let argsInfo = (0, cli_utils_1.getArgsData)(args, supportedArgs);
            let projectName = argsInfo === null || argsInfo === void 0 ? void 0 : argsInfo.projectName;
            let installationMethod = argsInfo === null || argsInfo === void 0 ? void 0 : argsInfo.installationMethod;
            if (projectName === '' || projectName == undefined) {
                projectName = yield (0, prompts_1.text)({
                    message: 'What is the name of your application?',
                    placeholder: 'my-app',
                    defaultValue: 'my-app',
                });
                if ((0, prompts_1.isCancel)(projectName)) {
                    (0, prompts_1.cancel)('Operation cancelled.');
                    process.exit(0);
                }
            }
            // copy directory
            const data = fs_1.default.cpSync(projectPath, path_1.default.join(process.cwd(), projectName), {
                recursive: true,
            });
            prompts_1.log.info(` Using \x1b[33m ${installationMethod} \x1b!`);
            installDependencies(projectName, installationMethod);
        });
    }
    main();
});
